@@ -106,14 +106,15 @@ qsynthSystemTray::~qsynthSystemTray (void)
 void qsynthSystemTray::updatePixmap (void)
 {
 	// Renitialize icon as fit...
-	m_pixmap = m_icon.pixmap(22, 22);
+	m_pixmap = m_icon.pixmap(32, 32);
 
 	// Merge with the overlay pixmap...
 	if (!m_pixmapOverlay.mask().isNull()) {
+		const int y = m_pixmap.height() - m_pixmapOverlay.height();
 		QBitmap mask = m_pixmap.mask();
-		QPainter(&mask).drawPixmap(0, 0, m_pixmapOverlay.mask());
+		QPainter(&mask).drawPixmap(0, y, m_pixmapOverlay.mask());
 		m_pixmap.setMask(mask);
-		QPainter(&m_pixmap).drawPixmap(0, 0, m_pixmapOverlay);
+		QPainter(&m_pixmap).drawPixmap(0, y, m_pixmapOverlay);
 	}
 
 	if (m_background != Qt::transparent) {
