@@ -164,19 +164,7 @@
         <translation>L&apos;option -o requiert un argument.</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="369"/>
-        <source>Qt: %1
-</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="371"/>
-        <source>%1: %2  (%3)
-</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="392"/>
+        <location filename="../qsynthOptions.cpp" line="391"/>
         <source>Unknown option &apos;%1&apos;.</source>
         <translation>Option &apos;%1&apos; inconnue.</translation>
     </message>
@@ -204,52 +192,52 @@
         <translation>À propos de Qt</translation>
     </message>
     <message>
-        <location filename="../qsynthAboutForm.cpp" line="43"/>
+        <location filename="../qsynthAboutForm.cpp" line="63"/>
         <source>Version</source>
         <translation>Version</translation>
     </message>
     <message>
         <location filename="../qsynthAboutForm.cpp" line="44"/>
-        <source>Build</source>
-        <translation>Compilé</translation>
+        <source>Debugging option enabled.</source>
+        <translation>Option de débogage activée.</translation>
     </message>
     <message>
         <location filename="../qsynthAboutForm.cpp" line="47"/>
-        <source>Debugging option enabled.</source>
-        <translation>Option de débuggage activée.</translation>
-    </message>
-    <message>
-        <location filename="../qsynthAboutForm.cpp" line="53"/>
         <source>System tray disabled.</source>
         <translation>Barre d&apos;état desactivée.</translation>
     </message>
     <message>
-        <location filename="../qsynthAboutForm.cpp" line="58"/>
+        <location filename="../qsynthAboutForm.cpp" line="50"/>
         <source>Server option disabled.</source>
         <translation>Option du serveur désactivée.</translation>
     </message>
     <message>
-        <location filename="../qsynthAboutForm.cpp" line="64"/>
+        <location filename="../qsynthAboutForm.cpp" line="53"/>
         <source>System reset option disabled.</source>
         <translation>Option de remise à zéro du système désactivée.</translation>
     </message>
     <message>
-        <location filename="../qsynthAboutForm.cpp" line="70"/>
+        <location filename="../qsynthAboutForm.cpp" line="56"/>
         <source>Bank offset option disabled.</source>
         <translation>Option de décalage de banque désactivée.</translation>
     </message>
     <message>
-        <location filename="../qsynthAboutForm.cpp" line="75"/>
+        <location filename="../qsynthAboutForm.cpp" line="72"/>
+        <source>Using: FluidSynth %1</source>
+        <translation>Utilisation de : FluidSynth %1</translation>
+    </message>
+    <message>
+        <location filename="../qsynthAboutForm.cpp" line="76"/>
         <source>Website</source>
         <translation>Site web</translation>
     </message>
     <message>
-        <location filename="../qsynthAboutForm.cpp" line="80"/>
+        <location filename="../qsynthAboutForm.cpp" line="81"/>
         <source>This program is free software; you can redistribute it and/or modify it</source>
         <translation>Ce programme est un programme libre; vous pouvez le redistribuer et/ou le modifier</translation>
     </message>
     <message>
-        <location filename="../qsynthAboutForm.cpp" line="81"/>
+        <location filename="../qsynthAboutForm.cpp" line="82"/>
         <source>under the terms of the GNU General Public License version 2 or later.</source>
         <translation>sous les termes de la license publique générale GNU version 2 ou plus récente.</translation>
     </message>
@@ -264,7 +252,7 @@
     <message>
         <location filename="../qsynthChannelsForm.ui" line="56"/>
         <source>Preset &amp;Name:</source>
-        <translation>&amp;Nom de pré-réglage :</translation>
+        <translation>&amp;Nom du pré-réglage :</translation>
     </message>
     <message>
         <location filename="../qsynthChannelsForm.ui" line="77"/>
@@ -377,7 +365,7 @@
     <message>
         <location filename="../qsynthMainForm.ui" line="34"/>
         <source>Qsynth - A fluidsynth Qt GUI Interface</source>
-        <translation>Qsynth - Une interface graphique Qt pour fluidsynth</translation>
+        <translation>Qsynth - une interface graphique Qt pour fluidsynth</translation>
     </message>
     <message>
         <location filename="../qsynthMainForm.ui" line="49"/>
@@ -1039,7 +1027,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="145"/>
         <source>Whether to keep a maximum number of lines in the messages window</source>
-        <translation>Si on doit conserver un nombre minimum de lignes dans la fenêtre de messages</translation>
+        <translation>Si on doit conserver un nombre maximum de lignes dans la fenêtre de messages</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="148"/>
@@ -1104,7 +1092,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="283"/>
         <source>Whether to activate a messages logging to file.</source>
-        <translation>Doit on activer l&apos;enregistrement des messages dans un fichier.</translation>
+        <translation>Doit-on activer l&apos;enregistrement des messages dans un fichier.</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="286"/>
@@ -1180,7 +1168,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="455"/>
         <source>Whether to ask for confirmation on application exit</source>
-        <translation>Doit on demander une confirmation lors de la fermeture de l&apos;application</translation>
+        <translation>Doit-on demander une confirmation lors de la fermeture de l&apos;application</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="458"/>
@@ -1205,7 +1193,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="471"/>
         <source>Whether to keep all child windows on top of the main window</source>
-        <translation>Doit on conserver toutes les sous fenêtres au dessus de la fenêtre principale</translation>
+        <translation>Doit-on conserver toutes les sous-fenêtres au dessus de la fenêtre principale</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="474"/>
@@ -1215,7 +1203,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="487"/>
         <source>Whether to capture standard output (stdout/stderr) into messages window</source>
-        <translation>Doit on capturer la sortie standard (stdout/stderr) dans la fenêtre de messages</translation>
+        <translation>Doit-on capturer la sortie standard (stdout/stderr) dans la fenêtre de messages</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="490"/>
@@ -1225,7 +1213,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="503"/>
         <source>Whether to monitor and show engine output peak level meters</source>
-        <translation>Doit on suivre et afficher le niveau de la sortie crête du moteur audio</translation>
+        <translation>Doit-on suivre et afficher le niveau de crête en sortie du moteur audio</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="506"/>
@@ -1235,7 +1223,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="532"/>
         <source>Whether to enable the system tray icon</source>
-        <translation>Doit on activer l&apos;icône de la barre d&apos;état</translation>
+        <translation>Doit-on activer l&apos;icône de la barre d&apos;état</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="535"/>
@@ -1245,7 +1233,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="564"/>
         <source>Whether to start minimized to system tray</source>
-        <translation>Doit on démarrer minimisé dans la barre d&apos;état</translation>
+        <translation>Doit-on démarrer minimisé dans la barre d&apos;état</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="567"/>
@@ -1426,7 +1414,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="118"/>
         <source>&amp;Dump MIDI router events</source>
-        <translation>Afficher les évènement du routeur MI&amp;DI</translation>
+        <translation>Afficher les évènements du routeur MI&amp;DI</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="131"/>
@@ -1594,7 +1582,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="462"/>
         <source>Buffer Cou&amp;nt:</source>
-        <translation>&amp;Nombre de tampon :</translation>
+        <translation>&amp;Nombre de tampons :</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="475"/>
@@ -1739,7 +1727,7 @@ le redémarrage du moteur fluidsynth :</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="817"/>
         <source>&amp;Multiple JACK Outputs</source>
-        <translation>Sorties JACK &amp;Multiples</translation>
+        <translation>Sorties JACK &amp;multiples</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="841"/>
